==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/nb.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Sirkler",
    "Circles' files" : "Filer tilhørende sirkler",
    "Select circles to filter by" : "Velg sirkler å filtrere etter",
    "No circles found" : "Ingen sirkler funnet",
    "Please select circles to filter by" : "Velg sirkler å filtrere etter",
    "No files found for the selected circles" : "Ingen filer funnet for valgte sirkler",
    "You created the circle {circle}" : "Du opprettet sirkelen {circle}",
    "{author} created the circle {circle}" : "{author} opprettet sirkelen {circle}",
    "You deleted {circle}" : "Du slettet {circle}",
    "{author} deleted {circle}" : "{author} slettet {circle}",
    "You linked {group} to {circle}" : "Du lenket {group} til {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} har blitt lenket til {circle} av {author}",
    "You unlinked {group} from {circle}" : "Du fjernet lenke til {group} fra {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} har fått sin lenke til {circle} fjernet av {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du har endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "You sent a request to link {circle} with {remote}" : "Du sendte en forespørsel om å lenke {circle} med {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendte en forespørsel om å lenke {circle} med {remote}",
    "{remote} requested a link with {circle}" : "{remote} forespurte en lenke med {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Forespørselen om å lenke {circle} med {remote} har blitt avslått",
    "The request to link {remote} with {circle} has been canceled remotely" : "Forespørselen om å lenke {remote} med {circle} har blitt avslått eksternt",
    "The request to link {circle} with {remote} has been accepted" : "Forespørselen om å lenke {circle} med {remote} har blitt godtatt",
    "You dismissed the request to link {remote} with {circle}" : "Du har avslått forespørselen om å lenke {remote} med {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} avslo forespørselen om å lenke {remote} med {circle}",
    "You canceled the request to link {circle} with {remote}" : "Du avbrøt forespørselen om å lenke {circle} med {link}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} avbrøt forespørselen om å lenke {circle} med {remote}",
    "You accepted the request to link {remote} with {circle}" : "Du godtok forespørselen om å lenke {remote} med {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} godtok forespørselen om å lenke {remote} med {circle}",
    "A link between {circle} and {remote} is now up and running" : "En lenke mellom {circle} og {remote} er nå oppe og går",
    "The link between {circle} and {remote} has been shutdown remotely" : "Lenken mellom {circle} og {remote} har blitt fjernet eksternt",
    "You closed the link between {circle} and {remote}" : "Du lukket lenken mellom {circle} og {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} lukket lenken mellom {circle} og {remote}",
    "You joined {circle}" : "Du tok del i {circle}",
    "{member} joined {circle}" : "{member} tok del i {circle}",
    "You accepted the invitation to join {circle}" : "Du godtok invitasjonen om å ta del i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} godtok invitasjonen til å ta del i {circle}",
    "You added {member} as member to {circle}" : "Du la til {member} som medlem i {circle}",
    "You have been added as member to {circle} by {author}" : "Du har blitt lagt til som medlem av {circle} av {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er lagt til som medlem i {circle} av {author}",
    "You added {external} to {circle}" : "Du la {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} har blitt lagt til {circle} av {author}",
    "You accepted {member}'s request to join {circle}" : "Du godtok {member} sin forespørsel om å ta del i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} sin forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "You left {circle}" : "Du forlot {circle}",
    "{member} left {circle}" : "{member} forlot {circle}",
    "You declined the invitation to join {circle}" : "Du avslo invitasjonen til å delta i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} avslo invitasjonen til å delta i {circle}",
    "You cancelled your request to join {circle}" : "Du avbrøt ønsket om å delta i {circle}",
    "{member} cancelled his request to join {circle}" : "{member} avbrøt ønsker om å bli med i {circle}",
    "You removed {member} from {circle}" : "Du fjernet {member} fra {circle}",
    "You have been removed from {circle} by {author}" : "Du ble fjernet fra {circle} av {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ble fjernet fra {circle} av {author}",
    "You removed {external} from {circle}" : "Du fjernet {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} har blitt fjernet fra {circle} av {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du avbrøt {member}s invitasjon til å bli med i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitasjon til å bli med i {circle} ble avbrutt av {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} avbrøt {member}'s invitasjon til å bli med i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du avslo {member}s ønske om å bli med i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ditt ønske om å bli med i {circle} ble avslått av {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s ønske om å bli med i {circle} ble avslått av {author}",
    "You invited {member} to join {circle}" : "Du inviterte {member} til å delta i {circle}",
    "You have been invited to join {circle} by {author}" : "Du har blitt invitert inn i {circle} av {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er invitert inn i {circle} av {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du endret {member}s nivå i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} endret ditt nivå i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} endret {member}s nivå i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte et ønske om å bli med i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
    "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Ønsker du å bli varslet om hendelser i <strong>sirkler</strong> du modererer?",
    "Shared to Circles" : "Delt til Sirkler",
    "Personal" : "Personlig",
    "Contact" : "Kontakt",
    "Circle" : "Sirkel",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Eier",
    "%s shared »%s« with you." : "%s delte »%s« med deg.",
    "%s on %s" : "%s på %s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne \"%s\"",
    "Circle not found" : "Fant ikke sirkelen",
    "A circle with that name exists" : "En sirkel med det navnet finnes",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kan ikke bruke sirkel-appen før administratoren din har tillat minst én type sirkler",
    "This member does not exist" : "Dette medlemmet finnes ikke",
    "This user is already a member of the circle" : "Denne brukeren er allerede medlem av sirkelen",
    "Federated link not found" : "Fant ikke den sammenknyttede lenken",
    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
    "The circle is not federated" : "Sirkelen er ikke sammenknyttet",
    "You cannot join this circle" : "Du kan ikke tilslutte deg denne sirkelen",
    "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
    "Insufficient privileges" : "Utilstrekkelige rettigheter",
    "This member is the owner of the circle" : "Dette medlemmet eier denne sirkelen",
    "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
    "The user is already a member of this circle" : "Brukeren er allerede medlem av denne sirkelen",
    "The user has already been invited into this circle" : "Brukeren er allerede invitert inn i denne sirkelen",
    "Accept" : "Aksepter",
    "You need a specify a type of circle" : "Du må oppgi sirkeltype",
    "This member is not the owner of the circle" : "Dette medlemmet eier ikke denne sirkelen",
    "This member is not an admin of the circle" : "Dette medlemmet er ikke administrator av sirkelen",
    "This group does not exist" : "Denne gruppen finnes ikke",
    "This group is already linked to the circle" : "Gruppen er allerede lenket til sirkelen",
    "You cannot edit level in a personal circle" : "Du kan ikke endre nivå i en personlig sirkel",
    "Group cannot be set as owner of a circle" : "Gruppe kan ikke settes som eier av en sirkel",
    "now" : "nå",
    "This user does not exist" : "Denne brukeren finnes ikke",
    "Email format is not valid" : "E-postadressen er ikke gyldig",
    "This contact is not available" : "Denne kontakten er ikke tilgjengelig",
    "Could not find share" : "Kunne ikke finne ressurs",
    "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "Maximum number of members per circle" : "Makimalt antall brukere per sirkel",
    "Allow linking of groups" : "Tillat linking av grupper",
    "Groups can be linked to circles." : "Grupper kan lenkes til sirkler.",
    "Are you sure you want to transfer your ownership?" : "Er du sikker på at du vil overføre ditt eierskap?",
    "This action is irreversible" : "Denne handlingen kan ikke angres.",
    "Personal circle" : "Personlig sirkel",
    "Secret circle" : "Hemmelig sirkel",
    "Closed circle" : "Lukket sirkel",
    "Public circle" : "Offentlig sirkel",
    "Link Removed" : "Lenke fjernet",
    "Link down" : "Lenke nede",
    "Setting link" : "Setter lenke",
    "Request dismissed" : "Forespørsel avslått",
    "Request sent" : "Forespørsel sendt",
    "Link requested" : "Lenke forespurt",
    "Link up" : "Lenke oppe",
    "Personal Circle" : "Personlig sirkel",
    "Secret Circle" : "Hemmelig sirkel",
    "Closed Circle" : "Lukket sirkel",
    "Public Circle" : "Offentlig sirkel",
    "Secret" : "Hemmelig",
    "Closed" : "Lukket",
    "Public" : "Offentlig",
    "Not a member" : "Ikke et medlem",
    "Unknown" : "Ukjent",
    "Invited" : "Invitert",
    "Requesting" : "Forespør",
    "Blocked" : "Blokkert",
    "Kicked" : "Utkastet",
    "This operation will add/invite all members of the group to the circle" : "Dette vil legge til/invitere alle medlemmer av gruppen til sirkelen",
    "Please confirm" : "Bekreft",
    "Are you sure you want to leave this circle?" : "Er du sikker på at du vil forlate denne sirkelen?",
    "Are you sure you want to delete this circle?" : "Er du sikker på at du vil slette denne sirkelen?",
    "Mail Address" : "E-postadresse",
    "Kick this member" : "Kast ut dette medlemmet",
    "Accept the request" : "Aksepter forespørselen",
    "Dismiss the request" : "Avslå forespørselen",
    "Unlink this group" : "Fjern denne gruppen",
    "Remove this link" : "Fjern denne lenken",
    "Cancel the link request" : "Avbryt denne lenkeforespørselen",
    "Accept the link request" : "Godta denne lenkeforespørselen",
    "Reject the link request" : "Avslå lenkeforespørselen",
    "Cannot join this circle" : "Kan ikke ta del i denne sirkelen",
    "no error message" : "ingen feilmelding",
    "You have joined this circle" : "Du har tatt del i denne sirkelen",
    "You have requested to join this circle" : "Du har forespurt deltagelse i denne sirkelen",
    "You have left this circle" : "Du har forlatt denne sirkelen",
    "Cannot leave this circle" : "Kan ikke forlate denne sirkelen",
    "You have deleted this circle" : "Du har slettet denne sirkelen",
    "Cannot delete this circle" : "Kan ikke slette denne sirkelen",
    " {type} '{name}' created" : " {type} '{name}' opprettet",
    " {type} '{name}' could not be created" : " {type} '{name}' kunne ikke opprettes",
    "Issue while retrieving the details of this circle" : "Feil ved innhenting av sirkeldetaljer for denne sirkelen",
    "Issue while retrieving the list of circles" : "Feil ved innhenting av sirkel-listen",
    "Group '{name}' successfully added to the circle" : "Gruppen '{name}' ble lagt til i sirkelen",
    "Group '{name}' could not be added to the circle" : "Gruppen '{name}' kunne ikke legges til i sirkelen",
    "Group '{name}' updated" : "Gruppen '{name}' ble oppdatert",
    "Group '{name}' could not be updated" : "Gruppen '{name}' kunne ikke oppdateres",
    "Group '{name}' successfully removed from the circle" : "Gruppen '{name}' ble fjernet fra sirkelen",
    "Group '{name}' could not be removed from the circle" : "Gruppen '{name}' kunne ikke fjernes fra sirkelen",
    "A link to <b>{remote}</b> could not be initiated" : "En lenke til <b>{remote}</b> kunne ikke opprettes",
    "A link to <b>{remote}</b> has been requested." : "En lenke til <b>{remote}</b> har blitt forespurt.",
    "the link to <b>{remote}</b> is now up and running." : "lenken til <b>{remote}</b> er nå oppe og går.",
    "The status of the link could not be updated" : "Lenkens status kunne ikke oppdateres",
    "The status of the link has been updated" : "Statusen for lenken har blitt oppdatert",
    "Local User" : "Lokal bruker",
    "Local Group" : "Lokal gruppe",
    "The email address '{email}' was added to the circle" : "E-postadressen '{email}' ble lagt til i sirkelen",
    "The email address '{email}' could not be added to the circle" : "E-postadressen '{email}' kunne ikke legges til i sirkelen",
    "Members of the group '{name}' were added to the circle" : "Medlemmer av gruppen '{name}' ble innlemmet i sirkelen",
    "Members of the group '{name}' could not be added to the circle" : "Medlemmer av gruppen '{name}'  kunne ikke legges til i sirkelen",
    "Members of the group '{name}' were invited to the circle" : "Medlemmer av gruppen '{name}' ble invitert til sirkelen",
    "Members of the group '{name}' could not be invited to the circle" : "Medlemmer av gruppen '{name}' kunne ikke inviteres til sirkelen",
    "Issue while saving settings" : "Problem under lagring av innstillinger",
    "Settings saved." : "Innstillinger lagret.",
    "%s shared »%s« with '%s'." : "%s delte »%s« med '%s'.",
    "The name of your circle must contain at least 3 characters" : "Navnet på sirkelen din må inneholde minst 3 tegn",
    "Linked Groups are not allowed on this Nextcloud" : "Lenkede grupper er ikke tillatt i denne Nextclouden",
    "Federated circles are not allowed on this Nextcloud" : "Sammenknyttede sirkler tillates ikke i denne Nextcloud-en",
    "Sharing Frame does not exist" : "Delingsrammen finnes ikke",
    "You cannot create this type of circle" : "Du kan ikke opprette denne typen sirkel",
    "You cannot display this type of circle" : "Du kan ikke vise denne typen sirkel",
    "Federated link does not have a valid format" : "Sammenknyttet lenke ser ikke ut til å ha et gyldig format",
    "Federated circles are not allowed on the remote Nextcloud" : "Sammenknyttede sirkler tillates ikke på den eksternet Nextclouden",
    "Remote circle does not accept federated links" : "Ekstern sirkel hen tillater ikke sammenknyttede lenker",
    "Trying to link a circle to itself" : "Prøver å lenke en sirkel til seg selv",
    "This link exists already" : "Denne lenken finnes allerede",
    "The requested remote circle does not exist" : "Forespurt  ekstern sirkel finnes ikke",
    "The remote host is down or the Circles app is not installed on it" : "Serveren er nede eller så er ikke Sirkelappen installert på den",
    "Cannot proceed with this status update" : "Kan ikke fortsette med denne statusoppdateringen",
    "Create a new circle" : "Opprett en ny sirkel",
    "Select a circle type" : "Velg en sirkeltype",
    "Create a personal circle" : "Opprett en personlig sirkel",
    "Create a public circle" : "Opprett en offentlig sirkel",
    "Create a closed circle" : "Lag en lukket sirkel",
    "Create a secret circle" : "Lag en hemmelig sirkel",
    "Creation" : "Opprettelse",
    "A personal circle is a list of users known only to the owner." : "En personlig sirkel er en liste over brukere bare eieren vet om.",
    "This is the right option if you want to do recurrent sharing with the same list of local users." : "Dette er det rette valget hvis du ønsker å utføre gjentagende deling med samme liste av lokale brukere.",
    "A secret circle is an hidden group that can only be seen by its members or by people knowing the exact name of the circle." : "En hemmelig sirkel er en skjult gruppe som bare kan ses av dens medlemmer eller av folk som kjenner det eksakte navnet på sirkelen.",
    "Non-members won't be able to find your secret circle using the search bar." : "Ikke-medlemmer vil ikke kunne finne din hemmelige sirkel ved bruk av søkefeltet.",
    "Joining a closed circle requires an invitation or confirmation by a moderator." : "Å ta del i en lukket sirkel krever en invitasjon eller bekreftelse av en moderator.",
    "A public circle is an open group visible to anyone willing to join." : "En offentlig sirkel er en åpen gruppe synlig for alle som ønsker å ta del i den.",
    "Anyone can see, join, and access the items shared within the circle." : "Alle kan se, ta del i, og dele elementene delt i sirkelen.",
    "Personal circles" : "Personlige sirkler",
    "Public circles" : "Offentlige sirkler",
    "Closed circles" : "Lukkede sirkler",
    "Secret circles" : "Hemmelige sirkler",
    "All circles" : "Alle sirkler",
    "Search circles" : "Søk i sirkler",
    "No filter" : "Inget filter",
    "Circles you belong to" : "Sirkler du er en del av",
    "Circles you own" : "Sirkler du eier",
    "No circle selected" : "Ingen sirker er valgt",
    "Settings" : "Innstillinger",
    "Pending invitation to join this circle" : "Ventende invitasjon til å ta del i denne i sirkelen",
    "You have a pending request to join this circle" : "Du har en ventende forespørsel for deltagelse i denne sirkelen",
    "Add a member" : "Legg til en medlem",
    "Link a group" : "Lenk en gruppe",
    "Link a circle" : "Lenk sirkel",
    "Join this circle" : "Bli med i denne sirkelen",
    "Delete circle" : "Slett sirkel",
    "Edit circle" : "Endre sirkel",
    "Accept the invitation" : "Aksepter invitasjonen",
    "Decline the invitation" : "Avslå invitasjonen",
    "Leave this circle" : "Forlat denne sirkelen",
    "Link to a circle" : "Lenk til en sirkel",
    "Return to menu" : "Gå tilbake til meny",
    "Username" : "Brukernavn",
    "Level" : "Nivå",
    "Status" : "Status",
    "Joined" : "Ble med",
    "Group Name" : "Gruppenavn",
    "Link" : "Lenke",
    "Linked" : "Lenket",
    "Description" : "Beskrivelse",
    "Members limit" : "Medlemsbegrensning",
    "Change the limit to the number of members. (0: default, -1: unlimited)" : "Endre grense for antall medlemmer (0: standard, -1: udefinert).",
    "Change password" : "Endre passord",
    "Allow Federated Links" : "Tillat sammenknyttede lenker",
    "Makes the circle federated, and enables sharing between federated circles" : "Knytter sammen sirkelen, og skrur på deling mellom sammenknyttede sirkler",
    "Accept Link Request Automatically" : "Godta lenkeforespørsel automatisk",
    "Warning: Enabling this will automatically accept new link requests from other circles." : "Advarsel: Å skru på dette vil medføre automatisk godkjenning av nye lenkeforespørsler fra andre sirkler.",
    "Save settings" : "Lagre innstillinger"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/nb.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Sirkler",
    "Circles' files" : "Filer tilhørende sirkler",
    "Select circles to filter by" : "Velg sirkler å filtrere etter",
    "No circles found" : "Ingen sirkler funnet",
    "Please select circles to filter by" : "Velg sirkler å filtrere etter",
    "No files found for the selected circles" : "Ingen filer funnet for valgte sirkler",
    "You created the circle {circle}" : "Du opprettet sirkelen {circle}",
    "{author} created the circle {circle}" : "{author} opprettet sirkelen {circle}",
    "You deleted {circle}" : "Du slettet {circle}",
    "{author} deleted {circle}" : "{author} slettet {circle}",
    "You linked {group} to {circle}" : "Du lenket {group} til {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} har blitt lenket til {circle} av {author}",
    "You unlinked {group} from {circle}" : "Du fjernet lenke til {group} fra {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} har fått sin lenke til {circle} fjernet av {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du har endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "You sent a request to link {circle} with {remote}" : "Du sendte en forespørsel om å lenke {circle} med {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendte en forespørsel om å lenke {circle} med {remote}",
    "{remote} requested a link with {circle}" : "{remote} forespurte en lenke med {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Forespørselen om å lenke {circle} med {remote} har blitt avslått",
    "The request to link {remote} with {circle} has been canceled remotely" : "Forespørselen om å lenke {remote} med {circle} har blitt avslått eksternt",
    "The request to link {circle} with {remote} has been accepted" : "Forespørselen om å lenke {circle} med {remote} har blitt godtatt",
    "You dismissed the request to link {remote} with {circle}" : "Du har avslått forespørselen om å lenke {remote} med {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} avslo forespørselen om å lenke {remote} med {circle}",
    "You canceled the request to link {circle} with {remote}" : "Du avbrøt forespørselen om å lenke {circle} med {link}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} avbrøt forespørselen om å lenke {circle} med {remote}",
    "You accepted the request to link {remote} with {circle}" : "Du godtok forespørselen om å lenke {remote} med {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} godtok forespørselen om å lenke {remote} med {circle}",
    "A link between {circle} and {remote} is now up and running" : "En lenke mellom {circle} og {remote} er nå oppe og går",
    "The link between {circle} and {remote} has been shutdown remotely" : "Lenken mellom {circle} og {remote} har blitt fjernet eksternt",
    "You closed the link between {circle} and {remote}" : "Du lukket lenken mellom {circle} og {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} lukket lenken mellom {circle} og {remote}",
    "You joined {circle}" : "Du tok del i {circle}",
    "{member} joined {circle}" : "{member} tok del i {circle}",
    "You accepted the invitation to join {circle}" : "Du godtok invitasjonen om å ta del i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} godtok invitasjonen til å ta del i {circle}",
    "You added {member} as member to {circle}" : "Du la til {member} som medlem i {circle}",
    "You have been added as member to {circle} by {author}" : "Du har blitt lagt til som medlem av {circle} av {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er lagt til som medlem i {circle} av {author}",
    "You added {external} to {circle}" : "Du la {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} har blitt lagt til {circle} av {author}",
    "You accepted {member}'s request to join {circle}" : "Du godtok {member} sin forespørsel om å ta del i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} sin forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "You left {circle}" : "Du forlot {circle}",
    "{member} left {circle}" : "{member} forlot {circle}",
    "You declined the invitation to join {circle}" : "Du avslo invitasjonen til å delta i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} avslo invitasjonen til å delta i {circle}",
    "You cancelled your request to join {circle}" : "Du avbrøt ønsket om å delta i {circle}",
    "{member} cancelled his request to join {circle}" : "{member} avbrøt ønsker om å bli med i {circle}",
    "You removed {member} from {circle}" : "Du fjernet {member} fra {circle}",
    "You have been removed from {circle} by {author}" : "Du ble fjernet fra {circle} av {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ble fjernet fra {circle} av {author}",
    "You removed {external} from {circle}" : "Du fjernet {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} har blitt fjernet fra {circle} av {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du avbrøt {member}s invitasjon til å bli med i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitasjon til å bli med i {circle} ble avbrutt av {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} avbrøt {member}'s invitasjon til å bli med i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du avslo {member}s ønske om å bli med i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ditt ønske om å bli med i {circle} ble avslått av {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s ønske om å bli med i {circle} ble avslått av {author}",
    "You invited {member} to join {circle}" : "Du inviterte {member} til å delta i {circle}",
    "You have been invited to join {circle} by {author}" : "Du har blitt invitert inn i {circle} av {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er invitert inn i {circle} av {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du endret {member}s nivå i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} endret ditt nivå i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} endret {member}s nivå i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte et ønske om å bli med i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
    "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Ønsker du å bli varslet om hendelser i <strong>sirkler</strong> du modererer?",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Åpne",
    "Hidden" : "Skjult",
    "Local" : "Lokal",
    "Root" : "Rot",
    "Federated" : "Sammenknyttet",
    "Contact" : "Kontakt",
    "Circle" : "Sirkel",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Eier",
    "%s shared »%s« with you." : "%s delte »%s« med deg.",
    "%s on %s" : "%s på %s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne \"%s\"",
    "Circle not found" : "Fant ikke sirkelen",
    "This member does not exist" : "Dette medlemmet finnes ikke",
    "Federated link not found" : "Fant ikke den sammenknyttede lenken",
    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
    "The circle is not federated" : "Sirkelen er ikke sammenknyttet",
    "You cannot join this circle" : "Du kan ikke tilslutte deg denne sirkelen",
    "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
    "Insufficient privileges" : "Utilstrekkelige rettigheter",
    "This member is the owner of the circle" : "Dette medlemmet eier denne sirkelen",
    "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
    "Accept" : "Aksepter",
    "%s" : "%s",
    "Personal Circle" : "Personlig sirkel",
    "You need a specify a type of circle" : "Du må oppgi sirkeltype",
    "A circle with that name exists" : "En sirkel med det navnet finnes",
    "This member is not the owner of the circle" : "Dette medlemmet eier ikke denne sirkelen",
    "This member is not an admin of the circle" : "Dette medlemmet er ikke administrator av sirkelen",
    "This group does not exist" : "Denne gruppen finnes ikke",
    "This group is already linked to the circle" : "Gruppen er allerede lenket til sirkelen",
    "You cannot edit level in a personal circle" : "Du kan ikke endre nivå i en personlig sirkel",
    "Group cannot be set as owner of a circle" : "Gruppe kan ikke settes som eier av en sirkel",
    "now" : "nå",
    "Email format is not valid" : "E-postadressen er ikke gyldig",
    "This contact is not available" : "Denne kontakten er ikke tilgjengelig",
    "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kan ikke bruke sirkel-appen før administratoren din har tillat minst én type sirkler",
    "This user is already a member of the circle" : "Denne brukeren er allerede medlem av sirkelen",
    "The user is already a member of this circle" : "Brukeren er allerede medlem av denne sirkelen",
    "The user has already been invited into this circle" : "Brukeren er allerede invitert inn i denne sirkelen",
    "This user does not exist" : "Denne brukeren finnes ikke",
    "Could not find share" : "Kunne ikke finne ressurs"
},
"nplurals=2; plural=(n != 1);");
